@@ -8,9 +8,9 @@ def setup_settings(settings, is_prod, **kwargs):
     if 'solo' not in settings['INSTALLED_APPS']:
         settings['INSTALLED_APPS'] += ['solo']
 
-    settings['CONTEXT_PROCESSORS'] += [
-        'exchange.context_processors.currencies'
-    ]
+    for template in settings['TEMPLATES']:
+        template['OPTIONS']['context_processors'].append(
+            'exchange.context_processors.currencies')
 
 
 class ExchangeAppConfig(AppConfig):
